/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package javax.net.ssl;

import java.security.Principal;
import java.security.cert.Certificate;
import javax.security.cert.X509Certificate;

public interface SSLSession {
    byte[] getId();
    SSLSessionContext getSessionContext() throws SecurityException;
    long getCreationTime();
    long getLastAccessedTime();
    void invalidate();
    boolean isValid();
    void putValue(String name, Object value) throws IllegalArgumentException;
    Object getValue(String name) throws IllegalArgumentException;
    void removeValue(String name) throws IllegalArgumentException;
    String[] getValueNames();
    Certificate[] getPeerCertificates() throws SSLPeerUnverifiedException;
    Certificate[] getLocalCertificates();
    X509Certificate[] getPeerCertificateChain() throws SSLPeerUnverifiedException;
    Principal getPeerPrincipal() throws SSLPeerUnverifiedException;
    Principal getLocalPrincipal();
    String getCipherSuite();
    String getProtocol();
    String getPeerHost();
    int getPeerPort();
    int getPacketBufferSize();
    int getApplicationBufferSize();
}
